"use strict";
/**
 * Copyright © 2019 kevinpollet <pollet.kevin@gmail.com>`
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE.md file.
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = __importDefault(require("fs"));
const util_1 = require("util");
const readPkg_1 = require("../utils/readPkg");
const getSemverTags_1 = require("./getSemverTags");
exports.getBuildConfig = (dir) => __awaiter(void 0, void 0, void 0, function* () {
    const [pkgJson, rootFiles] = yield Promise.all([
        readPkg_1.readPkg(dir),
        util_1.promisify(fs_1.default.readdir)(dir),
    ]);
    const { author = {}, description, name, version, bin, main } = pkgJson;
    const useYarn = rootFiles.includes("yarn.lock");
    const configFiles = rootFiles.filter(name => name === ".npmrc" || (name === ".yarnrc" && useYarn));
    const lockFile = rootFiles.find(name => name === (useYarn ? "yarn.lock" : "package-lock.json"));
    return {
        name,
        useYarn,
        configFiles,
        lockFile,
        tags: getSemverTags_1.getSemverTags(version),
        entrypoint: (bin && Object.values(bin)[0]) || main || "index.js",
        labels: Object.assign(Object.assign(Object.assign({}, (version ? { version } : undefined)), (description ? { description } : undefined)), (author.email ? { maintainer: author.email } : undefined)),
    };
});
