"use strict";
/**
 * Copyright © 2019 kevinpollet <pollet.kevin@gmail.com>`
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE.md file.
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fast_glob_1 = __importDefault(require("fast-glob"));
const tar_fs_1 = __importDefault(require("tar-fs"));
const generateDockerfile_1 = require("./generateDockerfile");
const listModuleDependencies_1 = require("./utils/listModuleDependencies");
exports.createDockerBuildContext = (dir, config) => __awaiter(void 0, void 0, void 0, function* () {
    const [extraFiles, moduleDependencies] = yield Promise.all([
        fast_glob_1.default(config.extraFiles || [], { cwd: dir }),
        listModuleDependencies_1.listModuleDependencies(dir, config.entrypoint),
    ]);
    const entries = [
        ...moduleDependencies,
        ...extraFiles,
        ...(config.configFiles || []),
        "package.json",
    ];
    if (config.lockFile) {
        entries.push(config.lockFile);
    }
    return tar_fs_1.default.pack(dir, {
        entries,
        finalize: false,
        finish(pack) {
            pack.entry({ name: "Dockerfile" }, generateDockerfile_1.generateDockerfile(config));
            pack.entry({ name: ".dockerignore" }, "*");
            pack.finalize();
        },
    });
});
