"use strict";
/**
 * Copyright © 2019 kevinpollet <pollet.kevin@gmail.com>`
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE.md file.
 */
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const nunjucks_1 = __importDefault(require("nunjucks"));
const normalizePkgRegistryUrl_1 = require("./utils/normalizePkgRegistryUrl");
const dockerfileTemplate = `
{% set comma = joiner(" ") %}

FROM node:10-alpine AS builder
{{ "ARG AUTH_TOKEN" if pkgRegistryAuth }}
WORKDIR app

{% if configFiles and configFiles.length > 0 %}
  COPY {% for file in configFiles %}{{ comma() }}{{ file }}{% endfor %} ./
{% endif %}

COPY package.json {{ lockFile if lockFile }} ./

{% set installCommand = "npm install --production --no-package-lock" %}
{% if useYarn %}
  {% set installCommand = "yarn install --production --pure-lockfile" %}
{% endif %}

{% if not pkgRegistryAuth %}
  RUN {{ installCommand }}
{% else %}
  RUN echo -e 'always-auth=true\\n{{normalizePkgRegistryUrl(pkgRegistryAuth.url)}}:_authToken=\${AUTH_TOKEN}\\n' >> ~/.npmrc && \
    {{ installCommand }} && \
    rm -rf ~/.npmrc
{% endif %}

COPY . .

FROM gcr.io/distroless/nodejs

{% if labels %}
  LABEL {% for key, value in labels %}{{ comma() }}"{{ key }}"="{{value}}"{% endfor %}
{% endif %}

WORKDIR app
COPY --from=builder app/ ./

{% if ports %}
  EXPOSE {% for port in ports %}{{ comma() }}{{ port }}{% endfor %}
{% endif %}

ENTRYPOINT ["/nodejs/bin/node", "{{ entrypoint }}"]
`;
exports.generateDockerfile = (config) => nunjucks_1.default.renderString(dockerfileTemplate, Object.assign(Object.assign({}, config), { normalizePkgRegistryUrl: normalizePkgRegistryUrl_1.normalizePkgRegistryUrl }));
